package javax.swing.colorchooser;

import javax.swing.event.ChangeEvent;
import javax.swing.JSpinner;
import javax.swing.JSlider;
import javax.swing.SpinnerNumberModel;
import javax.swing.JComponent;
import javax.swing.event.ChangeListener;

final class SlidingSpinner implements ChangeListener
{
    private final ColorPanel panel;
    private final JComponent label;
    private final SpinnerNumberModel model;
    private final JSlider slider;
    private final JSpinner spinner;
    private float value;
    private boolean internal;
    
    SlidingSpinner(ColorPanel panel, JComponent label) {
        this.model = new SpinnerNumberModel();
        this.slider = new JSlider();
        this.spinner = new JSpinner(this.model);
        this.panel = panel;
        this.label = label;
        this.slider.addChangeListener(this);
        this.spinner.addChangeListener(this);
        JSpinner.DefaultEditor defaultEditor = (JSpinner.DefaultEditor)this.spinner.getEditor();
        ValueFormatter.init(3, false, defaultEditor.getTextField());
        defaultEditor.setFocusable(false);
        this.spinner.setFocusable(false);
    }
    
    JComponent getLabel() {
        return this.label;
    }
    
    JSlider getSlider() {
        return this.slider;
    }
    
    JSpinner getSpinner() {
        return this.spinner;
    }
    
    float getValue() {
        return this.value;
    }
    
    void setValue(float value) {
        int minimum = this.slider.getMinimum();
        int maximum = this.slider.getMaximum();
        this.internal = true;
        this.slider.setValue(minimum + (int)(value * (float)(maximum - minimum)));
        this.spinner.setValue(Integer.valueOf(this.slider.getValue()));
        this.internal = false;
        this.value = value;
    }
    
    void setRange(int n, int n2) {
        this.internal = true;
        this.slider.setMinimum(n);
        this.slider.setMaximum(n2);
        this.model.setMinimum(Integer.valueOf(n));
        this.model.setMaximum(Integer.valueOf(n2));
        this.internal = false;
    }
    
    void setVisible(boolean visible) {
        this.label.setVisible(visible);
        this.slider.setVisible(visible);
        this.spinner.setVisible(visible);
    }
    
    @Override
    public void stateChanged(ChangeEvent changeEvent) {
        if (!this.internal) {
            if (this.spinner == changeEvent.getSource()) {
                Object value = this.spinner.getValue();
                if ((value instanceof Integer)) {
                    this.internal = true;
                    this.slider.setValue((int)value);
                    this.internal = false;
                }
            }
            int value2 = this.slider.getValue();
            this.internal = true;
            this.spinner.setValue(Integer.valueOf(value2));
            this.internal = false;
            int minimum = this.slider.getMinimum();
            this.value = (float)(value2 - minimum) / (float)(this.slider.getMaximum() - minimum);
            this.panel.colorChanged();
        }
    }
}
